@@ -2,30 +2,32 @@ package Mojolicious::Plugin::Util::RandomString;
 use Mojo::Base 'Mojolicious::Plugin';
 use Session::Token;
 
-our $VERSION = 0.03;
+our $VERSION = '0.04';
 
-my (%generator, %default, %setting);
-my $read_config;
-
-our $ok;
+our (%generator, %setting, %default, %param);
+our $read_config;
+our $ok = 1;
 
 # Register plugin
 sub register {
   my ($plugin, $mojo, $param) = @_;
 
-  $ok = undef;
-
-  $param //= {};
+  $ok--;
 
   if (ref $param ne 'HASH') {
     $mojo->log->fatal(__PACKAGE__ . ' expects a hash reference');
     return;
   };
 
+  if ($param) {
+    $param{$_} = $param->{$_} foreach keys %$param;
+  };
+
+
   # Load parameter from Config file
   unless ($read_config) {
     if (my $config_param = $mojo->config('Util-RandomString')) {
-      $param = { %$config_param, %$param };
+      %param =  ( %$config_param, %param );
     };
     $read_config = 1;
   };
@@ -37,29 +39,29 @@ sub register {
       my %created = ();
 
       # Create generators by param
-      foreach (keys %$param) {
+      foreach (keys %param) {
 
 	# Named generator
-	if (ref $param->{$_} && ref $param->{$_} eq 'HASH') {
+	if (ref $param{$_} && ref $param{$_} eq 'HASH') {
 
 	  next if $created{$_};
 
 	  # Construct object
 	  unless ($generator{$_} = Session::Token->new(
-	    %{ $param->{$_} }
+	    %{ $param{$_} }
 	  )) {
 
 	    # Unable to construct object
 	    $mojo->log->fatal(qq!Unable to create generator for "$_"!);
 	    next;
 	  };
-	  $setting{$_} = { %{ $param->{$_} } };
+	  $setting{$_} = { %{$param{$_}} };
 	  $created{$_} = 1;
 	}
 
 	# Default parameter
 	else {
-	  $default{$_} = $param->{$_};
+	  $default{$_} = $param{$_};
 	};
       };
 
@@ -67,21 +69,23 @@ sub register {
       $ok++;
 
       # Create default generator
-      $generator{'default'} //= Session::Token->new( %default );
+      unless (exists $generator{default}) {
+	$generator{default} = Session::Token->new( %default );
+      };
     });
 
 
   # Establish 'random_string' helper
   $mojo->helper(
     random_string => sub {
-
-      my $gen = $_[1];
+      shift;
+      my $gen = $_[0];
 
       # One tick for loop until the plugin is registered
-      Mojo::IOLoop->one_tick until Mojo::IOLoop->is_running || $ok;
+      Mojo::IOLoop->one_tick until Mojo::IOLoop->is_running || $ok > 0;
 
       # Generate from generator
-      unless ($_[2]) {
+      unless ($_[1]) {
 
 	# Generator doesn't exist
 	if ($gen && !exists $generator{$gen}) {
@@ -90,12 +94,9 @@ sub register {
 	};
 
 	# Get from generator
-	return $generator{$gen // 'default'}->get;
+	return $generator{$gen || 'default'}->get;
       };
 
-      # Controller
-      shift;
-
       # Overwrite default configuration
       return Session::Token->new(%default, @_)->get unless @_ % 2;
 
